====================
ilds
====================

**ilds** 是一个常用模块的集合，为了多平台，多电脑调用方便

** 还没有上传到 github **

功能模块包含:

* 获取文件md5
* 处理文件内容

安装：
-------------
pip install -U ilds


简单的例子:
-------------

.. code-block:: python

   import ilds

   from lds.file import is_file
 


更新日志
-------------

0.0.5
^^^^^^^^^^
* 修正路径问题

0.0.7
^^^^^^^^^^
* 添加了更多文件处理函数
* 添加了更多时间处理函数
* 添加了获取ip地址的函数

0.0.9
^^^^^^^^^^
* 把安装包加入到官方的pip服务器
* 修改包名字为 ilds 因为 lds 已经被使用
* 导入还是使用 lds

0.1.0
^^^^^^^^^^
* 导入统一修改为 ilds
* 修改说明文档为 rst 格式
